@@ -2,6 +2,7 @@ use strict;
 use warnings FATAL => 'all';
 
 package HTML::Tested::Value;
+use HTML::Entities;
 
 sub new {
 	my ($class, $parent, $name, @args) = @_;
@@ -15,11 +16,17 @@ sub value_to_string {
 	return $val;
 }
 
+sub encode_value {
+	my ($self, $val) = @_;
+	die "Non scalar value $val" if ref($val);
+	return encode_entities($val);
+}
+
 sub render {
 	my ($self, $caller, $stash, $id) = @_;
 	my $n = $self->name;
 	my $val = $caller->$n;
-	$val = '' unless defined($val);
+	$val = defined($val) ? $self->encode_value($val) : '';
 	$stash->{$n} = $self->value_to_string($id, $val);
 }
 
